@@ -7,7 +7,7 @@ import numpy as np
 def compute_permutation_distance(
     distance_matrix: np.ndarray, permutation: List[int]
 ) -> float:
-    """Compute distance of a given permutation
+    """Compute the total route distance of a given permutation
 
     Parameters
     ----------
@@ -16,12 +16,12 @@ def compute_permutation_distance(
         distance from node i to j. It does not need to be symmetric
 
     permutation
-        A list with nodes from 0 to n-1 in any order
+        A list with nodes from 0 to n - 1 in any order
 
     Returns
     -------
-    Total distance of the path given in `permutation` for the provided
-    `distance_matrix`
+    Total distance of the path given in ``permutation`` for the provided
+    ``distance_matrix``
 
     Notes
     -----
@@ -30,8 +30,8 @@ def compute_permutation_distance(
     can be fetched from a distance matrix using:
 
         distance_matrix[ind1, ind2], where
-        ind1 = [0, 1, 2, 3] # the FROM nodes
-        ind2 = [1, 2, 3, 0] # the TO nodes
+        ind1 = [0, 1, 2, 3]  # the FROM nodes
+        ind2 = [1, 2, 3, 0]  # the TO nodes
 
     This can easily be generalized to any permutation by using ind1 as the
     given permutation, and moving the first node to the end to generate ind2.
